@@ -17,15 +17,17 @@
 
   angular
     .module('horizon.framework', [
+      'ngRoute',
       'horizon.framework.conf',
       'horizon.framework.util',
       'horizon.framework.widgets'
     ])
     .config(config)
     .run(run)
-    .factory('horizon.framework.redirect', httpRedirectLogin)
+    .factory('horizon.framework.redirect', redirect)
+    .config(registerNotFound)
     .constant('horizon.framework.events', {
-      AUTH_ERROR: 'AUTH_ERROR'
+      FORCE_LOGOUT: 'FORCE_LOGOUT'
     });
 
   config.$inject = [
@@ -74,7 +76,7 @@
     // Global http error handler
     // if user is not authorized, log user out
     // this can happen when session expires
-    $httpProvider.interceptors.push(httpRedirectLogin);
+    $httpProvider.interceptors.push(redirect);
     $httpProvider.interceptors.push(stripAjaxHeaderForCORS);
 
     stripAjaxHeaderForCORS.$inject = [];
@@ -115,7 +117,7 @@
     }
   }
 
-  httpRedirectLogin.$inject = [
+  redirect.$inject = [
     '$q',
     '$rootScope',
     '$window',
@@ -123,33 +125,50 @@
     'horizon.framework.widgets.toast.service'
   ];
 
-  function httpRedirectLogin($q, $rootScope, $window, frameworkEvents, toastService) {
+  function redirect($q, $rootScope, $window, frameworkEvents, toastService) {
     return {
       responseError: function (error) {
         if (error.status === 401) {
           var msg = gettext('Unauthorized. Redirecting to login');
-          handleRedirectMessage(msg, $rootScope, $window, frameworkEvents, toastService, true);
+          handleRedirectMessage(msg, $rootScope, $window, frameworkEvents, toastService);
         }
         if (error.status === 403) {
-          var msg2 = gettext('Forbidden. Insufficient permissions of the requested operation');
-          handleRedirectMessage(msg2, $rootScope, $window, frameworkEvents, toastService, false);
+          var msg2 = gettext('Forbidden. Redirecting to login');
+          handleRedirectMessage(msg2, $rootScope, $window, frameworkEvents, toastService);
         }
         return $q.reject(error);
+      },
+      notFound: function() {
+        $window.location.href = $window.WEBROOT + 'not_found';
       }
     };
   }
 
-  function handleRedirectMessage(
-      msg, $rootScope, $window, frameworkEvents, toastService, forceLogout) {
+  function handleRedirectMessage(msg, $rootScope, $window, frameworkEvents, toastService) {
     var toast = toastService.find('error', msg);
     //Suppress the multiple duplicate redirect toast messages.
     if (!toast) {
       toastService.add('error', msg);
-      $rootScope.$broadcast(frameworkEvents.AUTH_ERROR, msg);
-    }
-    if (forceLogout) {
-      $window.location.replace($window.WEBROOT + 'auth/logout');
+      $rootScope.$broadcast(frameworkEvents.FORCE_LOGOUT, msg);
     }
+    $window.location.replace($window.WEBROOT + 'auth/logout');
+  }
+
+  registerNotFound.$inject = [
+    '$routeProvider'
+  ];
+
+  /**
+   * @name registerNotFound
+   * @param {Object} $routeProvider
+   * @description Routes to "not_found".
+   * @returns {undefined} Returns nothing
+   */
+  function registerNotFound($routeProvider) {
+    // if identifier not specified for "ngdetails"
+    $routeProvider.when('/ngdetails/:resourceType', {
+      redirectTo: "/not_found"
+    });
   }
 
 })();
