@@ -60,6 +60,7 @@ INSTALLED_APPS = (
 )
 
 MIDDLEWARE = (
+    'openstack_auth.middleware.OpenstackAuthMonkeyPatchMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
@@ -84,6 +85,7 @@ TEMPLATES = [
                 'django.contrib.messages.context_processors.messages',
                 'horizon.context_processors.horizon',
             ],
+            'debug': True,
             'loaders': [
                 'django.template.loaders.filesystem.Loader',
                 'django.template.loaders.app_directories.Loader',
@@ -157,10 +159,6 @@ LOGGING = {
             'handlers': ['test'],
             'propagate': False,
         },
-        'nose.plugins.manager': {
-            'handlers': ['null'],
-            'propagate': False,
-        },
         'selenium': {
             'handlers': ['null'],
             'propagate': False,
