@@ -10,12 +10,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns
 from django.conf.urls import url
 
-from horizon.test.test_dashboards.cats.tigers.views import IndexView  # noqa
+from horizon.test.test_dashboards.cats.tigers.views import IndexView
 
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(r'^$', IndexView.as_view(), name='index'),
-)
+]
