@@ -21,7 +21,7 @@ from six.moves import html_parser
 
 # regex to find filter translation expressions
 filter_regex = re.compile(
-    r"""{\$\s*(::)?\s*('([^']|\\')+'|"([^"]|\\")+")\s*\|\s*translate\s*\$}"""
+    r"""{\$\s*('([^']|\\')+'|"([^"]|\\")+")\s*\|\s*translate\s*\$}"""
 )
 
 # browser innerHTML decodes some html entities automatically, so when
@@ -49,8 +49,6 @@ class AngularGettextHTMLParser(html_parser.HTMLParser):
     {$ 'content' | translate $}
         The string will be translated, minus expression handling (i.e. just
         bare strings are allowed.)
-    {$ ::'content' | translate $}
-        The string will be translated. As above.
     """
 
     def __init__(self):
@@ -75,14 +73,14 @@ class AngularGettextHTMLParser(html_parser.HTMLParser):
         self.line = self.getpos()[0]
         if tag == 'translate' or \
                 (attrs and 'translate' in [attr[0] for attr in attrs]):
-                self.in_translate = True
-                self.plural_form = ''
-                for attr, value in attrs:
-                    if attr == 'translate-plural':
-                        self.plural = True
-                        self.plural_form = value
-                    if attr == 'translate-comment':
-                        self.comments.append(value)
+            self.in_translate = True
+            self.plural_form = ''
+            for attr, value in attrs:
+                if attr == 'translate-plural':
+                    self.plural = True
+                    self.plural_form = value
+                if attr == 'translate-comment':
+                    self.comments.append(value)
         elif self.in_translate:
             s = tag
             if attrs:
@@ -96,7 +94,7 @@ class AngularGettextHTMLParser(html_parser.HTMLParser):
                 for match in filter_regex.findall(attr[1]):
                     if match:
                         self.strings.append(
-                            (self.line, u'gettext', match[1][1:-1], [])
+                            (self.line, u'gettext', match[0][1:-1], [])
                         )
 
     def handle_data(self, data):
@@ -105,7 +103,7 @@ class AngularGettextHTMLParser(html_parser.HTMLParser):
         else:
             for match in filter_regex.findall(data):
                 self.strings.append(
-                    (self.line, u'gettext', match[1][1:-1], [])
+                    (self.line, u'gettext', match[0][1:-1], [])
                 )
 
     def handle_entityref(self, name):
@@ -125,7 +123,7 @@ class AngularGettextHTMLParser(html_parser.HTMLParser):
 
     def handle_endtag(self, tag):
         if self.in_translate:
-            if len(self.inner_tags) > 0:
+            if self.inner_tags:
                 tag = self.inner_tags.pop()
                 self.data += "</%s>" % tag
                 return
