@@ -20,6 +20,8 @@
 import collections
 import logging
 
+from oslo_utils import uuidutils
+
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 import six
@@ -70,12 +72,14 @@ VERSIONS = IdentityAPIVersionManager(
 
 # Import from oldest to newest so that "preferred" takes correct precedence.
 try:
+    # pylint: disable=ungrouped-imports
     from keystoneclient.v2_0 import client as keystone_client_v2
     VERSIONS.load_supported_version(2.0, {"client": keystone_client_v2})
 except ImportError:
     pass
 
 try:
+    # pylint: disable=ungrouped-imports
     from keystoneclient.v3 import client as keystone_client_v3
     VERSIONS.load_supported_version(3, {"client": keystone_client_v3})
 except ImportError:
@@ -243,7 +247,7 @@ def domain_lookup(request):
             return dict((d.id, d.name) for d in domains)
         except Exception:
             LOG.warning("Pure project admin doesn't have a domain token")
-            return None
+            return {}
     else:
         domain = get_default_domain(request)
         return {domain.id: domain.name}
@@ -347,6 +351,9 @@ def is_domain_admin(request):
 # tenant commands.
 @profiler.trace
 def tenant_get(request, project, admin=True):
+    if not uuidutils.is_uuid_like(project):
+        raise keystone_exceptions.NotFound()
+
     manager = VERSIONS.get_project_manager(request, admin=admin)
     try:
         return manager.get(project)
@@ -466,6 +473,9 @@ def user_delete(request, user_id):
 
 @profiler.trace
 def user_get(request, user_id, admin=True):
+    if not uuidutils.is_uuid_like(user_id):
+        raise keystone_exceptions.NotFound()
+
     user = keystoneclient(request, admin=admin).users.get(user_id)
     return VERSIONS.upgrade_v2_user(user)
 
@@ -586,9 +596,12 @@ def user_update_tenant(request, user, project, admin=True):
 @profiler.trace
 def group_create(request, domain_id, name, description=None):
     manager = keystoneclient(request, admin=True).groups
-    return manager.create(domain=domain_id,
-                          name=name,
-                          description=description)
+    try:
+        return manager.create(domain=domain_id,
+                              name=name,
+                              description=description)
+    except keystone_exceptions.Conflict:
+        raise exceptions.Conflict()
 
 
 @profiler.trace
@@ -626,7 +639,7 @@ def group_list(request, domain=None, project=None, user=None, filters=None):
         project_groups = []
         for group in groups:
             roles = roles_for_group(request, group=group.id, project=project)
-            if roles and len(roles) > 0:
+            if roles:
                 project_groups.append(group)
         groups = project_groups
     return groups
@@ -635,9 +648,12 @@ def group_list(request, domain=None, project=None, user=None, filters=None):
 @profiler.trace
 def group_update(request, group_id, name=None, description=None):
     manager = keystoneclient(request, admin=True).groups
-    return manager.update(group=group_id,
-                          name=name,
-                          description=description)
+    try:
+        return manager.update(group=group_id,
+                              name=name,
+                              description=description)
+    except keystone_exceptions.Conflict:
+        raise exceptions.Conflict()
 
 
 @profiler.trace
@@ -807,7 +823,7 @@ def get_project_users_roles(request, project):
             # filter by project_id
             if ('project' in role_assignment.scope and
                     role_assignment.scope['project']['id'] == project):
-                    users_roles[user_id].append(role_id)
+                users_roles[user_id].append(role_id)
     return users_roles
 
 
@@ -891,7 +907,7 @@ def get_default_role(request):
             roles = []
             exceptions.handle(request)
         for role in roles:
-            if role.id == default or role.name == default:
+            if default in (role.id, role.name):
                 DEFAULT_ROLE = role
                 break
     return DEFAULT_ROLE
@@ -1114,6 +1130,9 @@ def application_credential_create(request, name, secret=None,
                                   roles=None, unrestricted=False):
     user = request.user.id
     manager = keystoneclient(request).application_credentials
-    return manager.create(name=name, user=user, secret=secret,
-                          description=description, expires_at=expires_at,
-                          roles=roles, unrestricted=unrestricted)
+    try:
+        return manager.create(name=name, user=user, secret=secret,
+                              description=description, expires_at=expires_at,
+                              roles=roles, unrestricted=unrestricted)
+    except keystone_exceptions.Conflict:
+        raise exceptions.Conflict()
