@@ -35,7 +35,6 @@ import six
 from horizon import exceptions
 from horizon import messages
 from horizon.utils.memoized import memoized
-from horizon.utils.memoized import memoized_with_request
 from openstack_dashboard.api import base
 from openstack_dashboard.api import nova
 from openstack_dashboard.contrib.developer.profiler import api as profiler
@@ -236,8 +235,6 @@ class SecurityGroup(NeutronAPIDictWrapper):
     def __init__(self, sg, sg_dict=None):
         if sg_dict is None:
             sg_dict = {sg['id']: sg['name']}
-        if 'security_group_rules' not in sg:
-            sg['security_group_rules'] = []
         sg['rules'] = [SecurityGroupRule(rule, sg_dict)
                        for rule in sg['security_group_rules']]
         super(SecurityGroup, self).__init__(sg)
@@ -435,9 +432,9 @@ class SecurityGroupManager(object):
         """
         if not cidr:
             cidr = None
-        if from_port < 0:
+        if isinstance(from_port, int) and from_port < 0:
             from_port = None
-        if to_port < 0:
+        if isinstance(to_port, int) and to_port < 0:
             to_port = None
         if isinstance(ip_protocol, int) and ip_protocol < 0:
             ip_protocol = None
@@ -690,13 +687,13 @@ class FloatingIpManager(object):
         else:
             router_ports = [p for p in ports
                             if p.device_owner in ROUTER_INTERFACE_OWNERS]
-        reachable_subnets = set([p.fixed_ips[0]['subnet_id']
-                                 for p in router_ports
-                                 if p.device_id in gw_routers])
+        reachable_subnets = set(p.fixed_ips[0]['subnet_id']
+                                for p in router_ports
+                                if p.device_id in gw_routers)
         # we have to include any shared subnets as well because we may not
         # have permission to see the router interface to infer connectivity
-        shared = set([s.id for n in network_list(self.request, shared=True)
-                      for s in n.subnets])
+        shared = set(s.id for n in network_list(self.request, shared=True)
+                     for s in n.subnets)
         return reachable_subnets | shared
 
     @profiler.trace
@@ -808,9 +805,9 @@ def get_auth_params_from_request(request):
     )
 
 
-@memoized_with_request(get_auth_params_from_request)
-def neutronclient(request_auth_params):
-    token_id, neutron_url, auth_url = request_auth_params
+@memoized
+def neutronclient(request):
+    token_id, neutron_url, auth_url = get_auth_params_from_request(request)
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
     c = neutron_client.Client(token=token_id,
@@ -1015,7 +1012,7 @@ def network_list(request, **params):
     networks = neutronclient(request).list_networks(**params).get('networks')
     # Get subnet list to expand subnet info in network list.
     subnets = subnet_list(request)
-    subnet_dict = dict([(s['id'], s) for s in subnets])
+    subnet_dict = dict((s['id'], s) for s in subnets)
     # Expand subnet list from subnet_id to values.
     for n in networks:
         # Due to potential timing issues, we can't assume the subnet_dict data
@@ -1331,14 +1328,14 @@ def port_list_with_trunk_types(request, **params):
     if 'tenant_id' in params:
         trunk_filters['tenant_id'] = params['tenant_id']
     trunks = neutronclient(request).list_trunks(**trunk_filters)['trunks']
-    parent_ports = set([t['port_id'] for t in trunks])
+    parent_ports = set(t['port_id'] for t in trunks)
     # Create a dict map for child ports (port ID to trunk info)
-    child_ports = dict([(s['port_id'],
-                         {'trunk_id': t['id'],
-                          'segmentation_type': s['segmentation_type'],
-                          'segmentation_id': s['segmentation_id']})
-                        for t in trunks
-                        for s in t['sub_ports']])
+    child_ports = dict((s['port_id'],
+                        {'trunk_id': t['id'],
+                         'segmentation_type': s['segmentation_type'],
+                         'segmentation_id': s['segmentation_id']})
+                       for t in trunks
+                       for s in t['sub_ports'])
 
     def _get_port_info(port):
         if port['id'] in parent_ports:
@@ -1597,8 +1594,9 @@ def floating_ip_pools_list(request):
 
 
 @memoized
-def tenant_floating_ip_list(request, all_tenants=False):
-    return FloatingIpManager(request).list(all_tenants=all_tenants)
+def tenant_floating_ip_list(request, all_tenants=False, **search_opts):
+    return FloatingIpManager(request).list(all_tenants=all_tenants,
+                                           **search_opts)
 
 
 def tenant_floating_ip_get(request, floating_ip_id):
@@ -1717,6 +1715,9 @@ def servers_update_addresses(request, servers, all_tenants=False):
         networks = list_resources_with_long_filters(
             network_list, 'id', frozenset([port.network_id for port in ports]),
             request=request)
+    except neutron_exc.NotFound as e:
+        LOG.error('Neutron resource does not exist. %s', e)
+        return
     except Exception as e:
         LOG.error('Unable to connect to Neutron: %s', e)
         error_message = _('Unable to connect to Neutron.')
@@ -1734,7 +1735,8 @@ def servers_update_addresses(request, servers, all_tenants=False):
         ports_floating_ips[fip.port_id].append(fip)
 
     # Map network id to its name
-    network_names = dict(((network.id, network.name) for network in networks))
+    network_names = dict((network.id, network.name_or_id)
+                         for network in networks)
 
     for server in servers:
         try:
@@ -1770,11 +1772,14 @@ def _server_get_addresses(request, server, ports, floating_ips, network_names):
     for port in instance_ports:
         network_name = network_names.get(port.network_id)
         if network_name is not None:
-            for fixed_ip in port.fixed_ips:
-                addresses[network_name].append(
-                    _format_address(port.mac_address,
-                                    fixed_ip['ip_address'],
-                                    u'fixed'))
+            if port.fixed_ips:
+                for fixed_ip in port.fixed_ips:
+                    addresses[network_name].append(
+                        _format_address(port.mac_address,
+                                        fixed_ip['ip_address'],
+                                        u'fixed'))
+            else:
+                addresses[network_name] = []
             port_fips = floating_ips.get(port.id, [])
             for fip in port_fips:
                 addresses[network_name].append(
@@ -1786,12 +1791,13 @@ def _server_get_addresses(request, server, ports, floating_ips, network_names):
 
 
 @profiler.trace
-@memoized_with_request(neutronclient)
-def list_extensions(neutron_api):
+@memoized
+def list_extensions(request):
     """List neutron extensions.
 
     :param request: django request object
     """
+    neutron_api = neutronclient(request)
     try:
         extensions_list = neutron_api.list_extensions()
     except exceptions.ServiceCatalogException:
@@ -1839,6 +1845,7 @@ def is_router_enabled(request):
     return (is_enabled_by_config('enable_router') and
             is_extension_supported(request, 'router'))
 
+
 # FEATURE_MAP is used to define:
 # - related neutron extension name (key: "extension")
 # - corresponding dashboard config (key: "config")
@@ -1969,6 +1976,12 @@ def policy_get(request, policy_id, **kwargs):
     return QoSPolicy(policy)
 
 
+@profiler.trace
+def policy_delete(request, policy_id):
+    """Delete QoS policy for a given policy id."""
+    neutronclient(request).delete_qos_policy(policy_id)
+
+
 @profiler.trace
 def list_availability_zones(request, resource=None, state=None):
     az_list = neutronclient(request).list_availability_zones().get(
@@ -1979,3 +1992,59 @@ def list_availability_zones(request, resource=None, state=None):
         az_list = [az for az in az_list if az['state'] == state]
 
     return sorted(az_list, key=lambda zone: zone['name'])
+
+
+class RBACPolicy(NeutronAPIDictWrapper):
+    """Wrapper for neutron RBAC Policy."""
+
+
+def rbac_policy_create(request, **kwargs):
+    """Create a RBAC Policy.
+
+    :param request: request context
+    :param target_tenant: target tenant of the policy
+    :param tenant_id: owner tenant of the policy(Not recommended)
+    :param object_type: network or qos_policy
+    :param object_id: object id of policy
+    :param action: access_as_shared or access_as_external
+    :return: RBACPolicy object
+    """
+    body = {'rbac_policy': kwargs}
+    rbac_policy = neutronclient(request).create_rbac_policy(
+        body=body).get('rbac_policy')
+    return RBACPolicy(rbac_policy)
+
+
+def rbac_policy_list(request, **kwargs):
+    """List of RBAC Policies."""
+    policies = neutronclient(request).list_rbac_policies(
+        **kwargs).get('rbac_policies')
+    return [RBACPolicy(p) for p in policies]
+
+
+def rbac_policy_update(request, policy_id, **kwargs):
+    """Update a RBAC Policy.
+
+    :param request: request context
+    :param policy_id: target policy id
+    :param target_tenant: target tenant of the policy
+    :return: RBACPolicy object
+    """
+    body = {'rbac_policy': kwargs}
+    rbac_policy = neutronclient(request).update_rbac_policy(
+        policy_id, body=body).get('rbac_policy')
+    return RBACPolicy(rbac_policy)
+
+
+@profiler.trace
+def rbac_policy_get(request, policy_id, **kwargs):
+    """Get RBAC policy for a given policy id."""
+    policy = neutronclient(request).show_rbac_policy(
+        policy_id, **kwargs).get('rbac_policy')
+    return RBACPolicy(policy)
+
+
+@profiler.trace
+def rbac_policy_delete(request, policy_id):
+    """Delete RBAC policy for a given policy id."""
+    neutronclient(request).delete_rbac_policy(policy_id)
