@@ -22,8 +22,8 @@ from oslo_utils import units
 from six.moves import builtins
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -107,7 +107,7 @@ class IndexView(tables.DataTableView):
                 msg = _('Unable to retrieve project list.')
                 exceptions.handle(self.request, msg)
 
-            tenant_dict = dict([(t.id, t.name) for t in tenants])
+            tenant_dict = dict((t.id, t.name) for t in tenants)
 
             for image in images:
                 image.tenant_name = tenant_dict.get(image.owner)
@@ -124,8 +124,8 @@ class IndexView(tables.DataTableView):
                 invalid_msg = ('API query is not valid and is ignored: '
                                '%(field)s=%(string)s')
                 try:
-                    filter_string = builtins.int(float(filter_string)
-                                                 * (units.Mi))
+                    filter_string = builtins.int(float(filter_string) *
+                                                 (units.Mi))
                     if filter_string >= 0:
                         filters[filter_field] = filter_string
                     else:
