@@ -17,14 +17,14 @@
 #    under the License.
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
 from horizon import tables
+from horizon import tabs
 from horizon.utils import memoized
-from horizon import views
 from horizon import workflows
 
 from openstack_dashboard import api
@@ -35,6 +35,8 @@ from openstack_dashboard.usage import quotas
 
 from openstack_dashboard.dashboards.identity.projects \
     import tables as project_tables
+from openstack_dashboard.dashboards.identity.projects \
+    import tabs as project_tabs
 from openstack_dashboard.dashboards.identity.projects \
     import workflows as project_workflows
 from openstack_dashboard.dashboards.project.overview \
@@ -94,8 +96,7 @@ class IndexView(tables.DataTableView):
             # selected, then search criteria must be provided and
             # return an empty list
             filter_first = getattr(settings, 'FILTER_DATA_FIRST', {})
-            if filter_first.get('identity.projects', False) and len(
-                    filters) == 0:
+            if filter_first.get('identity.projects', False) and not filters:
                 self._needs_filter_first = True
                 self._more = False
                 return tenants
@@ -154,11 +155,6 @@ class CreateProjectView(workflows.WorkflowView):
     workflow_class = project_workflows.CreateProject
 
     def get_initial(self):
-
-        if (api.keystone.is_multi_domain_enabled() and
-                not api.keystone.is_cloud_admin(self.request)):
-            self.workflow_class = project_workflows.CreateProjectNoQuota
-
         initial = super(CreateProjectView, self).get_initial()
 
         # Set the domain of the project
@@ -166,16 +162,6 @@ class CreateProjectView(workflows.WorkflowView):
         initial["domain_id"] = domain.id
         initial["domain_name"] = domain.name
 
-        # get initial quota defaults
-        if api.keystone.is_cloud_admin(self.request):
-            try:
-                quota_defaults = quotas.get_default_quota_data(self.request)
-                for field in quotas.QUOTA_FIELDS:
-                    initial[field] = quota_defaults.get(field).limit
-            except Exception:
-                error_msg = _('Unable to retrieve default quota values.')
-                self.add_error_to_step(error_msg, 'create_quotas')
-
         return initial
 
 
@@ -183,11 +169,6 @@ class UpdateProjectView(workflows.WorkflowView):
     workflow_class = project_workflows.UpdateProject
 
     def get_initial(self):
-
-        if (api.keystone.is_multi_domain_enabled() and
-                not api.keystone.is_cloud_admin(self.request)):
-            self.workflow_class = project_workflows.UpdateProjectNoQuota
-
         initial = super(UpdateProjectView, self).get_initial()
 
         project_id = self.kwargs['tenant_id']
@@ -222,7 +203,21 @@ class UpdateProjectView(workflows.WorkflowView):
                     exceptions.handle(self.request,
                                       _('Unable to retrieve project domain.'),
                                       redirect=reverse(INDEX_URL))
+        except Exception:
+            exceptions.handle(self.request,
+                              _('Unable to retrieve project details.'),
+                              redirect=reverse(INDEX_URL))
+        return initial
 
+
+class UpdateQuotasView(workflows.WorkflowView):
+    workflow_class = project_workflows.UpdateQuota
+
+    def get_initial(self):
+        initial = super(UpdateQuotasView, self).get_initial()
+        project_id = self.kwargs['tenant_id']
+        initial['project_id'] = project_id
+        try:
             # get initial project quota
             if keystone.is_cloud_admin(self.request):
                 quota_data = quotas.get_tenant_quota_data(self.request,
@@ -231,13 +226,15 @@ class UpdateProjectView(workflows.WorkflowView):
                     initial[field] = quota_data.get(field).limit
         except Exception:
             exceptions.handle(self.request,
-                              _('Unable to retrieve project details.'),
+                              _('Unable to retrieve project quotas.'),
                               redirect=reverse(INDEX_URL))
+        initial['disabled_quotas'] = quotas.get_disabled_quotas(self.request)
         return initial
 
 
-class DetailProjectView(views.HorizonTemplateView):
-    template_name = 'identity/projects/detail.html'
+class DetailProjectView(tabs.TabView):
+    tab_group_class = project_tabs.ProjectDetailTabs
+    template_name = 'horizon/common/_detail.html'
     page_title = "{{ project.name }}"
 
     def get_context_data(self, **kwargs):
@@ -248,11 +245,6 @@ class DetailProjectView(views.HorizonTemplateView):
         context["url"] = reverse(INDEX_URL)
         context["actions"] = table.render_row_actions(project)
 
-        if keystone.VERSIONS.active >= 3:
-            extra_info = getattr(settings, 'PROJECT_TABLE_EXTRA_INFO', {})
-            context['extras'] = dict(
-                (display_key, getattr(project, key, ''))
-                for key, display_key in extra_info.items())
         return context
 
     @memoized.memoized_method
@@ -265,3 +257,7 @@ class DetailProjectView(views.HorizonTemplateView):
                               _('Unable to retrieve project details.'),
                               redirect=reverse(INDEX_URL))
         return project
+
+    def get_tabs(self, request, *args, **kwargs):
+        project = self.get_data()
+        return self.tab_group_class(request, project=project, **kwargs)
