@@ -21,7 +21,7 @@
 Views for managing floating IPs.
 """
 
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from neutronclient.common import exceptions as neutron_exc
@@ -89,7 +89,9 @@ class IndexView(tables.DataTableView):
 
     def get_data(self):
         try:
-            floating_ips = api.neutron.tenant_floating_ip_list(self.request)
+            search_opts = self.get_filters()
+            floating_ips = api.neutron.tenant_floating_ip_list(self.request,
+                                                               **search_opts)
         except neutron_exc.ConnectionFailed:
             floating_ips = []
             exceptions.handle(self.request)
@@ -108,7 +110,7 @@ class IndexView(tables.DataTableView):
             floating_ip_pools = []
             exceptions.handle(self.request,
                               _('Unable to retrieve floating IP pools.'))
-        pool_dict = dict([(obj.id, obj.name) for obj in floating_ip_pools])
+        pool_dict = dict((obj.id, obj.name) for obj in floating_ip_pools)
 
         attached_instance_ids = [ip.instance_id for ip in floating_ips
                                  if ip.instance_id is not None]
@@ -124,7 +126,7 @@ class IndexView(tables.DataTableView):
                 exceptions.handle(self.request,
                                   _('Unable to retrieve instance list.'))
 
-            instances_dict = dict([(obj.id, obj.name) for obj in instances])
+            instances_dict = dict((obj.id, obj.name) for obj in instances)
 
         for ip in floating_ips:
             ip.instance_name = instances_dict.get(ip.instance_id)
