@@ -27,6 +27,7 @@ from django.utils.translation import pgettext_lazy
 from django.utils.translation import string_concat
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
+import netaddr
 
 from horizon import exceptions
 from horizon import messages
@@ -82,6 +83,7 @@ def is_deleting(instance):
 class DeleteInstance(policy.PolicyTargetMixin, tables.DeleteAction):
     policy_rules = (("compute", "os_compute_api:servers:delete"),)
     help_text = _("Deleted instances are not recoverable.")
+    default_message_level = "info"
 
     @staticmethod
     def action_present(count):
@@ -174,6 +176,49 @@ class SoftRebootInstance(RebootInstance):
             return True
 
 
+class RescueInstance(policy.PolicyTargetMixin, tables.LinkAction):
+    name = "rescue"
+    verbose_name = _("Rescue Instance")
+    classes = ("btn-rescue", "ajax-modal")
+    url = "horizon:project:instances:rescue"
+
+    def get_link_url(self, datum):
+        instance_id = self.table.get_object_id(datum)
+        return urls.reverse(self.url, args=[instance_id])
+
+    def allowed(self, request, instance):
+        return instance.status in ACTIVE_STATES
+
+
+class UnRescueInstance(tables.BatchAction):
+    name = 'unrescue'
+    classes = ("btn-unrescue",)
+
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Unrescue Instance",
+            u"Unrescue Instances",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Unrescued Instance",
+            u"Unrescued Instances",
+            count
+        )
+
+    def action(self, request, obj_id):
+        api.nova.server_unrescue(request, obj_id)
+
+    def allowed(self, request, instance=None):
+        if instance:
+            return instance.status == "RESCUE"
+        return False
+
+
 class TogglePause(tables.BatchAction):
     name = "pause"
     icon = "pause"
@@ -969,16 +1014,9 @@ def get_ips(instance):
     ip_groups = {}
 
     for ip_group, addresses in instance.addresses.items():
-        ip_groups[ip_group] = {}
-        ip_groups[ip_group]["floating"] = []
-        ip_groups[ip_group]["non_floating"] = []
-
-        for address in addresses:
-            if ('OS-EXT-IPS:type' in address and
-               address['OS-EXT-IPS:type'] == "floating"):
-                ip_groups[ip_group]["floating"].append(address)
-            else:
-                ip_groups[ip_group]["non_floating"].append(address)
+        ips = [addr['addr'] for addr in addresses]
+        ips.sort(key=lambda ip: netaddr.IPAddress(ip).version)
+        ip_groups[ip_group] = ips
 
     context = {
         "ip_groups": ip_groups,
@@ -1243,7 +1281,7 @@ class InstancesTable(tables.DataTable):
                           verbose_name=_("Power State"),
                           display_choices=POWER_DISPLAY_CHOICES)
     created = tables.Column("created",
-                            verbose_name=_("Time since created"),
+                            verbose_name=_("Age"),
                             filters=(filters.parse_isotime,
                                      filters.timesince_sortable),
                             attrs={'data-type': 'timesince'})
@@ -1269,6 +1307,7 @@ class InstancesTable(tables.DataTable):
                        EditInstanceSecurityGroups,
                        EditPortSecurityGroups,
                        ConsoleLink, LogLink,
+                       RescueInstance, UnRescueInstance,
                        TogglePause, ToggleSuspend, ToggleShelve,
                        ResizeLink, LockInstance, UnlockInstance,
                        SoftRebootInstance, RebootInstance,
