@@ -20,6 +20,8 @@ import subprocess
 import sys
 import warnings
 
+import six
+
 from django.conf import settings
 from django.core.management import base
 from django import template
@@ -83,8 +85,10 @@ context['PROJECT_DIR_NAME'] = os.path.basename(
     context['PROJECT_PATH'].split(context['PROJECT_ROOT'])[1])
 context['PROJECT_NAME'] = context['PROJECT_DIR_NAME']
 
+context['DEFAULT_WSGI_FILE'] = os.path.join(
+    context['PROJECT_PATH'], 'wsgi.py')
 context['WSGI_FILE'] = os.path.join(
-    context['PROJECT_PATH'], 'wsgi/horizon.wsgi')
+    context['PROJECT_PATH'], 'horizon_wsgi.py')
 
 VHOSTNAME = context['HOSTNAME'].split('.')
 VHOSTNAME[0] = context['PROJECT_NAME']
@@ -112,8 +116,10 @@ for cmd in APACHE2_VERSION_CMDS:
     if os.path.exists(cmd[0][0]):
         try:
             reg = re.compile(cmd[1])
-            res = reg.search(
-                subprocess.check_output(cmd[0], stderr=subprocess.STDOUT))
+            output = subprocess.check_output(cmd[0], stderr=subprocess.STDOUT)
+            if isinstance(output, six.binary_type):
+                output = output.decode()
+            res = reg.search(output)
             if res:
                 APACHE2_VERSION = res.group('version')
                 break
@@ -133,6 +139,8 @@ def find_apache_log_dir():
         if os.path.exists(log_dir) and os.path.isdir(log_dir):
             return log_dir
     return DEFAULT_LOG_DIR
+
+
 context['LOGDIR'] = find_apache_log_dir()
 
 
@@ -312,6 +320,10 @@ location you desire, e.g.::
 
         # Generate the apache configuration.
         elif options.get('apache'):
+            # first check if custom wsgi file exists, if not, use default:
+            if not os.path.exists(context['WSGI_FILE']):
+                context['WSGI_FILE'] = context['DEFAULT_WSGI_FILE']
+
             with open(
                 os.path.join(CURDIR, 'apache_vhost.conf.template'), 'r'
             ) as fp:
