@@ -17,15 +17,16 @@
   "use strict";
 
   describe('images service', function() {
-    var service;
+    var service, detailRoute;
     beforeEach(module('horizon.app.core.images'));
     beforeEach(inject(function($injector) {
       service = $injector.get('horizon.app.core.images.service');
+      detailRoute = $injector.get('horizon.app.core.detailRoute');
     }));
 
     it("getDetailsPath creates urls using the item's ID", function() {
       var myItem = {id: "1234"};
-      expect(service.getDetailsPath(myItem)).toBe('project/ngdetails/OS::Glance::Image/1234');
+      expect(service.getDetailsPath(myItem)).toBe(detailRoute + 'OS::Glance::Image/1234');
     });
 
     describe('imageType', function() {
@@ -118,6 +119,32 @@
         expect(result.$$state.value.data.updated_at).toBe('jul1');
       }));
     });
+
+    describe('getFilterFirstSettingPromise', function() {
+      var settings, deferred, location, scope;
+      beforeEach(inject(function($q, $injector, $rootScope, $location) {
+        settings = $injector.get('horizon.app.core.openstack-service-api.settings');
+        deferred = $q.defer();
+        location = $location;
+        scope = $rootScope.$new();
+        spyOn(settings, 'getSetting').and.returnValue(deferred.promise);
+      }));
+      it("provides a promise and resolves the promise when setting==true", function() {
+        location.path('/admin/images');
+        service.getFilterFirstSettingPromise();
+        deferred.resolve({'admin.images': true});
+        scope.$apply();
+        expect(settings.getSetting).toHaveBeenCalled();
+      });
+
+      it("provides a promise and resolves the promise when setting==false", function() {
+        service.getFilterFirstSettingPromise();
+        deferred.resolve({'admin.images': false});
+        scope.$apply();
+        expect(settings.getSetting).toHaveBeenCalled();
+      });
+
+    });
   });
 
 })();
