@@ -54,6 +54,7 @@
     registry.getResourceType(trunkResourceType)
       .setNames(gettext('Trunk'), gettext('Trunks'))
       .setSummaryTemplateUrl(basePath + 'summary.html')
+      .setDefaultIndexUrl('/project/trunks/')
       .setProperties(trunkProperties())
       .setListFunction(trunksService.getTrunksPromise)
       .tableColumns
@@ -61,11 +62,13 @@
         id: 'name_or_id',
         priority: 1,
         sortDefault: true,
+        classes: "word-wrap",
         urlFunction: trunksService.getDetailsPath
       })
       .append({
         id: 'port_id',
-        priority: 1
+        priority: 1,
+        urlFunction: trunksService.getPortDetailsPath
       })
       .append({
         id: 'subport_count',
