@@ -1150,9 +1150,7 @@ class NeutronApiSecurityGroupTests(test.APIMockTestCase):
     def _cmp_sg(self, exp_sg, ret_sg):
         self.assertEqual(exp_sg['id'], ret_sg.id)
         self.assertEqual(exp_sg['name'], ret_sg.name)
-        # When a SG has no rules, neutron API does not contain
-        # 'security_group_rules' field, so .get() method needs to be used.
-        exp_rules = exp_sg.get('security_group_rules', [])
+        exp_rules = exp_sg['security_group_rules']
         self.assertEqual(len(exp_rules), len(ret_sg.rules))
         for (exprule, retrule) in six.moves.zip(exp_rules, ret_sg.rules):
             self._cmp_sg_rule(exprule, retrule)
@@ -1252,9 +1250,17 @@ class NeutronApiSecurityGroupTests(test.APIMockTestCase):
     def test_security_group_rule_create_without_desc(self):
         self._test_security_group_rule_create(with_desc=False)
 
-    def _test_security_group_rule_create(self, with_desc):
-        sg_rule = [r for r in self.api_security_group_rules.list()
-                   if r['protocol'] == 'tcp' and r['remote_ip_prefix']][0]
+    def test_security_group_rule_create_with_custom_protocol(self):
+        self._test_security_group_rule_create(custom_ip_proto=True)
+
+    def _test_security_group_rule_create(self, with_desc=False,
+                                         custom_ip_proto=False):
+        if custom_ip_proto:
+            sg_rule = [r for r in self.api_security_group_rules.list()
+                       if r['protocol'] == '99'][0]
+        else:
+            sg_rule = [r for r in self.api_security_group_rules.list()
+                       if r['protocol'] == 'tcp' and r['remote_ip_prefix']][0]
         sg_id = sg_rule['security_group_id']
         secgroup = [sg for sg in self.api_security_groups.list()
                     if sg['id'] == sg_id][0]
@@ -1519,7 +1525,7 @@ class NeutronApiFloatingIpTests(test.APIMockTestCase):
             'enable_fip_topology_check': True,
         }
     )
-    @mock.patch.object(api.nova, 'novaclient')
+    @mock.patch.object(api._nova, 'novaclient')
     def test_floating_ip_target_list(self, mock_novaclient):
         ports = self.api_ports.list()
         # Port on the first subnet is connected to a router
@@ -1580,7 +1586,7 @@ class NeutronApiFloatingIpTests(test.APIMockTestCase):
         self.qclient.list_routers.assert_called_once_with()
         self.qclient.list_subnets.assert_called_once_with()
 
-    @mock.patch.object(api.nova, 'novaclient')
+    @mock.patch.object(api._nova, 'novaclient')
     def _test_target_floating_ip_port_by_instance(self, server, ports,
                                                   candidates, mock_novaclient):
         # list_ports and list_networks are called multiple times,
