@@ -39,7 +39,7 @@ urlpatterns = [
     url(r'^$', views.splash, name='splash'),
     url(r'^api/', include(rest.urls)),
     url(r'^header/', views.ExtensibleHeaderView.as_view()),
-    url(r'', include(horizon.urls)),
+    url(r'', horizon.base._wrapped_include(horizon.urls)),
 ]
 
 # add URL for ngdetails
