@@ -46,9 +46,9 @@ def import_dashboard_config(modules):
             if hasattr(submodule, 'DASHBOARD'):
                 dashboard = submodule.DASHBOARD
                 config[dashboard].update(submodule.__dict__)
-            elif (hasattr(submodule, 'PANEL')
-                  or hasattr(submodule, 'PANEL_GROUP')
-                  or hasattr(submodule, 'FEATURE')):
+            elif (hasattr(submodule, 'PANEL') or
+                  hasattr(submodule, 'PANEL_GROUP') or
+                  hasattr(submodule, 'FEATURE')):
                 # If enabled and local.enabled contains a same filename,
                 # the file loaded later (i.e., local.enabled) will be used.
                 name = submodule.__name__.rsplit('.', 1)[1]
@@ -110,8 +110,11 @@ def update_dashboards(modules, horizon_config, installed_apps):
     js_files = []
     js_spec_files = []
     scss_files = []
+    xstatic_modules = []
     panel_customization = []
     header_sections = []
+    extra_tabs = collections.defaultdict(tuple)
+    extra_steps = collections.defaultdict(tuple)
     update_horizon_config = {}
     for key, config in import_dashboard_config(modules):
         if config.get('DISABLED', False):
@@ -134,8 +137,8 @@ def update_dashboards(modules, horizon_config, installed_apps):
 
         add_exceptions = config.get('ADD_EXCEPTIONS', {}).items()
         for category, exc_list in add_exceptions:
-            exceptions[category] = tuple(set(exceptions.get(category, ())
-                                             + exc_list))
+            exceptions[category] = tuple(set(exceptions.get(category, ()) +
+                                             exc_list))
 
         angular_modules.extend(config.get('ADD_ANGULAR_MODULES', []))
         # avoid pulling in dashboard javascript dependencies multiple times
@@ -144,6 +147,7 @@ def update_dashboards(modules, horizon_config, installed_apps):
                          if f not in existing])
         js_spec_files.extend(config.get('ADD_JS_SPEC_FILES', []))
         scss_files.extend(config.get('ADD_SCSS_FILES', []))
+        xstatic_modules.extend(config.get('ADD_XSTATIC_MODULES', []))
         update_horizon_config.update(
             config.get('UPDATE_HORIZON_CONFIG', {}))
         if config.get('DASHBOARD'):
@@ -154,6 +158,12 @@ def update_dashboards(modules, horizon_config, installed_apps):
         elif config.get('PANEL') or config.get('PANEL_GROUP'):
             config.pop("__builtins__", None)
             panel_customization.append(config)
+        _extra_tabs = config.get('EXTRA_TABS', {})
+        for tab_key, tab_defs in _extra_tabs.items():
+            extra_tabs[tab_key] += tuple(tab_defs)
+        _extra_steps = config.get('EXTRA_STEPS', {})
+        for step_key, step_defs in _extra_steps.items():
+            extra_steps[step_key] += tuple(step_defs)
     # Preserve the dashboard order specified in settings
     dashboards = ([d for d in config_dashboards
                    if d not in disabled_dashboards] +
@@ -169,6 +179,9 @@ def update_dashboards(modules, horizon_config, installed_apps):
     horizon_config.setdefault('js_files', []).extend(js_files)
     horizon_config.setdefault('js_spec_files', []).extend(js_spec_files)
     horizon_config.setdefault('scss_files', []).extend(scss_files)
+    horizon_config.setdefault('xstatic_modules', []).extend(xstatic_modules)
+    horizon_config['extra_tabs'] = extra_tabs
+    horizon_config['extra_steps'] = extra_steps
 
     # apps contains reference to applications declared in the enabled folder
     # basically a list of applications that are internal and external plugins
@@ -242,7 +255,7 @@ def get_xstatic_dirs(XSTATIC_MODULES, HORIZON_CONFIG):
     it must be handled as a special case.
     """
     STATICFILES_DIRS = []
-    HORIZON_CONFIG['xstatic_lib_files'] = []
+    HORIZON_CONFIG.setdefault('xstatic_lib_files', [])
     for module_name, files in XSTATIC_MODULES:
         module = import_module(module_name)
         if module_name == 'xstatic.pkg.jquery_ui':
